@@ -4,8 +4,11 @@
 # If argument is '--no-print', do not print the result.
 
 use warnings; use strict;
+use Test::More;
 use rlib './lib';
 
+{ package Term::ReadLine::Stub; }
+
 BEGIN{
     # Do not test TR::Gnu !
     $ENV{PERL_RL} = 'Perl5';
@@ -13,7 +16,6 @@ BEGIN{
     $ENV{'COLUMNS'} = '80';
     $ENV{'LINES'}   = '25';
 };
-use lib './lib';
 
 # FIXME:
 # Until Term::ReadLine has Perl5 defined use
@@ -21,6 +23,7 @@ use lib './lib';
 
 use Term::ReadLine::Perl5;
 
+
 use Carp;
 $SIG{__WARN__} = sub { warn Carp::longmess(@_) };
 
@@ -30,9 +33,10 @@ my $non_interactive =
      ($ENV{PERL_MM_USE_DEFAULT} || $ENV{AUTOMATED_TESTING});
 if ($non_interactive) {
     no strict; no warnings;
-    print "1..0 # skip: not interactive; " .
-    "\$ENV{PERL_MM_NONINTERACTIVE}='$ENV{PERL_MM_NONINTERCTIVE}' \$ENV{AUTOMATED_TESTING}='$ENV{AUTOMATED_TESTING}'\n";
-  exit;
+    plan skip_all => "Not interactive: " .
+	"\$ENV{PERL_MM_NONINTERACTIVE}='$ENV{PERL_MM_NONINTERACTIVE}' \$ENV{AUTOMATED_TESTING}='$ENV{AUTOMATED_TESTING}'\n";
+} else {
+    plan;
 }
 
 my ($term, $no_print);
@@ -50,19 +54,20 @@ if (!@ARGV) {
   $term = new Term::ReadLine::Perl5 'Simple Perl calc', \*STDIN, \*STDOUT;
   $no_print = $ARGV[0] eq '--no-print';
 }
+
+# use Enbugger 'trepan'; Enbugger->stop;
 my $prompt = "Enter arithmetic or Perl expression: ";
 if ((my $l = $ENV{PERL_RL_TEST_PROMPT_MINLEN} || 0) > length $prompt) {
   $prompt =~ s/(?=:)/ ' ' x ($l - length $prompt)/e;
 }
-print "1..1\n";
 no strict;
-my $OUT = $term->OUT || \*STDOUT;
+my $OUT = $term->{OUT} || \*STDOUT;
 use strict;
 my %features = %{ $term->Features };
 if (%features) {
   my @f = %features;
   print $OUT "Features present: @f\n";
-  #$term->ornaments(1) if $features{ornaments};
+  $term->ornaments(1) if $features{ornaments};
 } else {
   print $OUT "No additional features present.\n";
 }
@@ -75,6 +80,7 @@ print $OUT <<EOP;
 	this word should be already entered.)
 
 EOP
+
 while ( defined (my $line = $term->readline($prompt, 'exit')) )
 {
     last if $line eq 'exit';
@@ -85,7 +91,19 @@ while ( defined (my $line = $term->readline($prompt, 'exit')) )
 	next;
     }
     print $OUT $res, "\n" unless $@ or $no_print;
-    $term->addhistory($line) if $line =~ /\S/ and !$features{autohistory};
+    $term->add_history($line) if $line =~ /\S/;
     $readline::rl_default_selected = !$readline::rl_default_selected;
 }
-print "ok 1\n";
+if (@ARGV) {
+    my $term2 = Term::ReadLine::Perl5->new('caroline test');
+    while ( defined (my $line = $term2->readline($prompt, 'exit2')) )
+    {
+	last if $line eq 'exit2';
+	my $res = eval($line) || '';
+	print $OUT "$res\n" unless $@ or $no_print;
+	$term2->add_history($line) if $line =~ /\S/;
+	$readline::rl_default_selected = !$readline::rl_default_selected;
+    };
+};
+ok(1);
+done_testing();
